# Snakerun <!-- omit in toc -->

A classic Snake game implemented in **Python** and played via cli.

[![PyPI version](https://img.shields.io/pypi/v/snakerun.svg?color=blue)](https://pypi.org/project/snakerun/)
[![Python Versions](https://img.shields.io/pypi/pyversions/snakerun.svg)](https://pypi.org/project/snakerun/)
[![License](https://img.shields.io/github/license/bhatishan2003/snakerun)](LICENSE)
[![Python application](https://github.com/bhatishan2003/snakerun/actions/workflows/python-app.yml/badge.svg)](https://github.com/bhatishan2003/snakerun/actions/workflows/python-app.yml)
[![Coverage](https://img.shields.io/codecov/c/github/bhatishan2003/snakerun)](https://codecov.io/gh/bhatishan2003/snakerun)

## Table of Contents <!-- omit in toc -->

- [Installation](#installation)
- [Usage](#usage)

---

## Installation

-   From PyPi

    ```bash
    pip install snakerun
    ```

-   From Source :

    ```bash
    git clone https://github.com/bhatishan2003/snakerun.git
    cd snakerun
    pip install .
    ```

## Usage

Run the following command in the terminal to play the game.

```bash
snakerun
```

![Snake Game Demo](assets/demo.gif)
